@@ -1,5 +1,5 @@
 contourview.fun <- function(fun,
-        center = NULL, dim = length(center),
+        center = NULL, dim = ifelse(is.null(center),2,length(center)),
         npoints = 20,
         col = "blue",
         nlevels = 10,
@@ -21,15 +21,17 @@ contourview.fun <- function(fun,
     
     axis <- t(combn(D, 2))
     
-    if (is.null(mfrow)) {
+    if (is.null(mfrow) && (D>2)) {
         nc <- round(sqrt(nrow(axis)))
         nl <- ceiling(nrow(axis)/nc)
         mfrow <- c(nc, nl)
     }
     
     if (!isTRUE(add)) {
-        close.screen( all.screens = TRUE )
-        split.screen(figs = mfrow)
+        if (D>2) {
+            close.screen( all.screens = TRUE )
+            split.screen(figs = mfrow)
+        }
         .split.screen.lim <<- matrix(NaN,ncol=4,nrow=D) # xmin,xmax,ymin,ymax matrix of limits, each row for one dim combination
     }
     
@@ -61,7 +63,7 @@ contourview.fun <- function(fun,
     
     ## Each 'id' will produce a RGL plot
     for (id in 1:dim(axis)[1]) {
-        screen(id)
+        if (D>2) screen(id)
         
         d <- axis[id,]
         
