@@ -23,15 +23,17 @@ contourview.km <- function(model, type = "UK",
     
     axis <- t(combn(D, 2))
     
-    if (is.null(mfrow)) {
+    if (is.null(mfrow) & D>2) {
         nc <- round(sqrt(nrow(axis)))
         nl <- ceiling(nrow(axis)/nc)
         mfrow <- c(nc, nl)
     }
     
     if (!isTRUE(add)) {
-        close.screen( all.screens = TRUE )
-        split.screen(figs = mfrow)
+        if (D>2) {
+            close.screen( all.screens = TRUE )
+            split.screen(figs = mfrow)
+        }
         .split.screen.lim <<- matrix(NaN,ncol=4,nrow=D) # xmin,xmax,ymin,ymax matrix of limits, each row for one dim combination
     }
     
@@ -81,7 +83,7 @@ contourview.km <- function(model, type = "UK",
     
     ## Each 'id' will produce a RGL plot
     for (id in 1:dim(axis)[1]) {
-        screen(id)
+        if (D>2) screen(id)
         
         d <- axis[id,]
         
@@ -114,7 +116,7 @@ contourview.km <- function(model, type = "UK",
         for (i1 in 1:npoints[1]) {
             for (i2 in 1:npoints[2]) {
                 i <- i1 + (i2-1) * npoints[1]
-                y <- predict.km(model, type = type, newdata = (x[i,]))
+                y <- predict.km(model, type = type, newdata = (x[i,]), checkNames=FALSE)
                 y_mean[i] <- yscale * y$mean
                 y_sd[i] <- abs(yscale) * y$sd
                 yd_mean[i1, i2] <- yscale * y$mean
